@@ -150,7 +150,7 @@ private:
             }
         }
         if (!cardFound) {
-            error(i18n("Failed to find the card with the serial number: %1", mSerial.c_str()));
+            error(i18n("Failed to find the card with the serial number: %1", QString::fromStdString(mSerial)));
             finished();
             return;
         }
@@ -158,7 +158,7 @@ private:
             if (KMessageBox::warningContinueCancel(parentWidgetOrView(), i18nc("@info",
                 "<p>This card already contains a key in this slot. Continuing will <b>overwrite</b> that key.</p>"
                 "<p>If there is no backup the existing key will be irrecoverably lost.</p>") +
-                i18n("The existing key has the fingerprint:") + QStringLiteral("<pre>%1</pre>").arg(existingKey.c_str()) +
+                i18n("The existing key has the fingerprint:") + QStringLiteral("<pre>%1</pre>").arg(QString::fromStdString(existingKey)) +
                 encKeyWarning,
                 i18nc("@title:window", "Overwrite existing key"),
                 KStandardGuiItem::cont(), KStandardGuiItem::cancel(), QString(), KMessageBox::Notify | KMessageBox::Dangerous)
@@ -171,8 +171,8 @@ private:
         const auto time = QDateTime::fromTime_t(mKey.creationTime());
         const auto timestamp = time.toString(QStringLiteral("yyyyMMdd'T'HHmmss"));
 #ifdef GPGME_SUBKEY_HAS_KEYGRIP
-        const QString cmd = QStringLiteral("KEYTOCARD --force %1 %2 OPENPGP.%3 %4").arg(mKey.keyGrip())
-                                                                                   .arg(mSerial.c_str())
+        const QString cmd = QStringLiteral("KEYTOCARD --force %1 %2 OPENPGP.%3 %4").arg(QString::fromLatin1(mKey.keyGrip()))
+                                                                                   .arg(QString::fromStdString(mSerial))
                                                                                    .arg(slot)
                                                                                    .arg(timestamp);
         ReaderStatus::mutableInstance()->startSimpleTransaction(cmd.toUtf8(), q_func(), "keyToCardDone");
@@ -202,7 +202,7 @@ void KeyToCardCommand::keyToCardDone(const GpgME::Error &err)
 {
     if (err) {
         d->error(i18nc("@info",
-                       "Moving the key to the card failed: %1", err.asString()),
+                       "Moving the key to the card failed: %1", QString::fromUtf8(err.asString())),
                         i18nc("@title", "Error"));
     } else if (!err.isCanceled()) {
         /* TODO DELETE_KEY is too strong, because it also deletes the stub
@@ -227,7 +227,7 @@ void KeyToCardCommand::keyToCardDone(const GpgME::Error &err)
 void KeyToCardCommand::deleteDone(const GpgME::Error &err)
 {
     if (err) {
-        d->error(i18nc("@info", "Failed to delete the key: %1", err.asString()),
+        d->error(i18nc("@info", "Failed to delete the key: %1", QString::fromUtf8(err.asString())),
                         i18nc("@title", "Error"));
     }
     d->finished();
